==> haskell-html-conduit-1.3.1-36-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-html-conduit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: html-conduit
version: 1.3.1
id: html-conduit-1.3.1-4fXEE6T34GQDr6FvwH4nXN
key: html-conduit-1.3.1-4fXEE6T34GQDr6FvwH4nXN
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/snoyberg/xml
synopsis: Parse HTML documents using xml-conduit datatypes.
description:
    This package uses tagstream-conduit for its parser. It automatically balances mismatched tags, so that there shouldn'\''t be any parse failures. It does not handle a full HTML document rendering, such as adding missing html and head tags. Note that, since version 1.3.1, it uses an inlined copy of tagstream-conduit with entity decoding bugfixes applied.
category: Web, Text, Conduit
abi: 13126eb72840e83bfc6a74757c6547b1
exposed: True
exposed-modules:
    Text.HTML.DOM
hidden-modules: Text.HTML.TagStream
import-dirs: /usr/lib/ghc-8.4.3/site-local/html-conduit-1.3.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/html-conduit-1.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/html-conduit-1.3.1
hs-libraries: HShtml-conduit-1.3.1-4fXEE6T34GQDr6FvwH4nXN
depends:
    base-4.11.1.0 transformers-0.5.5.0 bytestring-0.10.8.2
    containers-0.5.11.0 text-1.2.3.0
    resourcet-1.2.1-I5oi84Fds3fEsALgoQoNDA
    conduit-1.3.0.3-69KoIVNx0TVLvOnjPWsVja
    xml-conduit-1.8.0-ClPAq0dG1498wzBxsM2y76
    xml-types-0.3.6-FWN9dD9K4Pf2M2rvMuT5Tt
    attoparsec-0.13.2.2-5oKqcFqqk8HLoRElqn64fK
    conduit-extra-1.3.0-D2mBZw6jHWq3A9XqwnArHJ
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             resourcet-1.2.1-I5oi84Fds3fEsALgoQoNDA=dcbdc81671b5884f063aea7a644e0575
             conduit-1.3.0.3-69KoIVNx0TVLvOnjPWsVja=95a17956f651b4cddf6ae026fd262ccd
             xml-conduit-1.8.0-ClPAq0dG1498wzBxsM2y76=41267f521aceec33a49b8d0364e915c4
             xml-types-0.3.6-FWN9dD9K4Pf2M2rvMuT5Tt=d60c5437db670e030567a6d42bb218af
             attoparsec-0.13.2.2-5oKqcFqqk8HLoRElqn64fK=fff7ae21f45c1b0af12007963cebbf81
             conduit-extra-1.3.0-D2mBZw6jHWq3A9XqwnArHJ=a0a9060204169a49edf461d292b39f37
haddock-interfaces: /usr/share/doc/haskell-html-conduit/html/html-conduit.haddock
haddock-html: /usr/share/doc/haskell-html-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-html-conduit-1.3.1-37-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-html-conduit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: html-conduit
version: 1.3.1
id: html-conduit-1.3.1-IQ23ZgNexIsFR4saGYFfym
key: html-conduit-1.3.1-IQ23ZgNexIsFR4saGYFfym
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/snoyberg/xml
synopsis: Parse HTML documents using xml-conduit datatypes.
description:
    This package uses tagstream-conduit for its parser. It automatically balances mismatched tags, so that there shouldn'\''t be any parse failures. It does not handle a full HTML document rendering, such as adding missing html and head tags. Note that, since version 1.3.1, it uses an inlined copy of tagstream-conduit with entity decoding bugfixes applied.
category: Web, Text, Conduit
abi: 06ff5695fabe94ef61397b1f649198ec
exposed: True
exposed-modules:
    Text.HTML.DOM
hidden-modules: Text.HTML.TagStream
import-dirs: /usr/lib/ghc-8.4.3/site-local/html-conduit-1.3.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/html-conduit-1.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/html-conduit-1.3.1
hs-libraries: HShtml-conduit-1.3.1-IQ23ZgNexIsFR4saGYFfym
depends:
    base-4.11.1.0 transformers-0.5.5.0 bytestring-0.10.8.2
    containers-0.5.11.0 text-1.2.3.0
    resourcet-1.2.1-I5oi84Fds3fEsALgoQoNDA
    conduit-1.3.0.3-69KoIVNx0TVLvOnjPWsVja
    xml-conduit-1.8.0-B3jRhN4FymgBxETDF0MfEe
    xml-types-0.3.6-FWN9dD9K4Pf2M2rvMuT5Tt
    attoparsec-0.13.2.2-LRi8ukEwwi1GyId6oqTEFJ
    conduit-extra-1.3.0-4j5DaXyKuirAJK9sh69vxz
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             resourcet-1.2.1-I5oi84Fds3fEsALgoQoNDA=dcbdc81671b5884f063aea7a644e0575
             conduit-1.3.0.3-69KoIVNx0TVLvOnjPWsVja=95a17956f651b4cddf6ae026fd262ccd
             xml-conduit-1.8.0-B3jRhN4FymgBxETDF0MfEe=00626b7a116849b4cca79b99206c6ebd
             xml-types-0.3.6-FWN9dD9K4Pf2M2rvMuT5Tt=d60c5437db670e030567a6d42bb218af
             attoparsec-0.13.2.2-LRi8ukEwwi1GyId6oqTEFJ=b8f8a17746566009aae6e9799affc625
             conduit-extra-1.3.0-4j5DaXyKuirAJK9sh69vxz=7890d00a08a10fe933f51da56482ec4e
haddock-interfaces: /usr/share/doc/haskell-html-conduit/html/html-conduit.haddock
haddock-html: /usr/share/doc/haskell-html-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
